@@ -5,10 +5,12 @@ from .similarities import (
 from .matchers import ThresholdMatcher
 from .variators import Variator, Swap
 from .filters import DissimilarFilter, NonOverlappingFilter
+from .scorers import SimSumScorer, AbsoluteScorer, MinScorer, MaxScorer, RefuseToScoreException
 
 __all__ = [
     "NoopIndex", "ColumnsIndex", "JaroWinklerSimilarity", "StringSimilarity",
     "DateSimilarity", "ThresholdMatcher", "MultiIndex", "Variator", "Swap",
     "DissimilarFilter", "NonOverlappingFilter", "AbsoluteNumericalSimilarity",
     "RelativeNumericalSimilarity",
+    "SimSumScorer", "AbsoluteScorer", "MinScorer", "MaxScorer", "RefuseToScoreException"
 ]
